# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from decimal import Decimal
from stripe._stripe_object import UntypedStripeObject
from stripe.v2._amount import AmountParam
from typing import Dict, List
from typing_extensions import Literal, NotRequired, TypedDict


class AccountCreateParams(TypedDict):
    account_token: NotRequired[str]
    """
    The account token generated by the account token api.
    """
    configuration: NotRequired["AccountCreateParamsConfiguration"]
    """
    An Account Configuration which allows the Account to take on a key persona across Stripe products.
    """
    contact_email: NotRequired[str]
    """
    The primary contact email address for the Account.
    """
    contact_phone: NotRequired[str]
    """
    The default contact phone for the Account.
    """
    dashboard: NotRequired[Literal["express", "full", "none"]]
    """
    A value indicating the Stripe dashboard this Account has access to. This will depend on which configurations are enabled for this account.
    """
    defaults: NotRequired["AccountCreateParamsDefaults"]
    """
    Default values to be used on Account Configurations.
    """
    display_name: NotRequired[str]
    """
    A descriptive name for the Account. This name will be surfaced in the Stripe Dashboard and on any invoices sent to the Account.
    """
    identity: NotRequired["AccountCreateParamsIdentity"]
    """
    Information about the company, individual, and business represented by the Account.
    """
    include: NotRequired[
        List[
            Literal[
                "configuration.card_creator",
                "configuration.customer",
                "configuration.merchant",
                "configuration.recipient",
                "configuration.money_manager",
                "defaults",
                "future_requirements",
                "identity",
                "requirements",
            ]
        ]
    ]
    """
    Additional fields to include in the response.
    """
    metadata: NotRequired["Dict[str, str]|UntypedStripeObject[str]"]
    """
    Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
    """


class AccountCreateParamsConfiguration(TypedDict):
    card_creator: NotRequired["AccountCreateParamsConfigurationCardCreator"]
    """
    The CardCreator Configuration allows the Account to create and issue cards to users.
    """
    customer: NotRequired["AccountCreateParamsConfigurationCustomer"]
    """
    The Customer Configuration allows the Account to be used in inbound payment flows (i.e. customer-facing payment and billing flows).
    """
    merchant: NotRequired["AccountCreateParamsConfigurationMerchant"]
    """
    Enables the Account to act as a connected account and collect payments facilitated by a Connect platform. You must onboard your platform to Connect before you can add this configuration to your connected accounts. Utilize this configuration when the Account will be the Merchant of Record, like with Direct charges or Destination Charges with on_behalf_of set.
    """
    money_manager: NotRequired["AccountCreateParamsConfigurationMoneyManager"]
    """
    The Money Manager Configuration allows the Account to store and move funds using FinancialAccounts.
    """
    recipient: NotRequired["AccountCreateParamsConfigurationRecipient"]
    """
    The Recipient Configuration allows the Account to receive funds. Utilize this configuration if the Account will not be the Merchant of Record, like with Separate Charges & Transfers, or Destination Charges without on_behalf_of set.
    """


class AccountCreateParamsConfigurationCardCreator(TypedDict):
    capabilities: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilities"
    ]
    """
    Capabilities to request on the CardCreator Configuration.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilities(TypedDict):
    commercial: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercial"
    ]
    """
    Can create cards for commercial issuing use cases.
    """
    consumer: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumer"
    ]
    """
    Can create cards for consumer issuing use cases.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercial(
    TypedDict,
):
    celtic: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCeltic"
    ]
    """
    Can create commercial issuing cards with Celtic as BIN sponsor.
    """
    cross_river_bank: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBank"
    ]
    """
    Can create commercial issuing cards with Cross River Bank as BIN sponsor.
    """
    fifth_third: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThird"
    ]
    """
    Can create commercial issuing cards with Fifth Third as BIN sponsor.
    """
    lead: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialLead"
    ]
    """
    Can create commercial issuing cards with Stripe as BIN sponsor.
    """
    stripe: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripe"
    ]
    """
    Can create commercial issuing cards with Stripe as BIN sponsor.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCeltic(
    TypedDict,
):
    charge_card: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCard"
    ]
    """
    Can create commercial issuing charge cards with Celtic as BIN sponsor.
    """
    spend_card: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCard"
    ]
    """
    Can create commercial issuing spend cards with Celtic as BIN sponsor.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCard(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCardProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCardProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCardProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticChargeCardProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCard(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCardProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCardProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCardProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCelticSpendCardProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBank(
    TypedDict,
):
    charge_card: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCard"
    ]
    """
    Can create commercial issuing charge cards with Cross River Bank as BIN sponsor.
    """
    prepaid_card: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankPrepaidCard"
    ]
    """
    Can create commercial issuing prepaid cards with Cross River Bank as BIN sponsor.
    """
    spend_card: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCard"
    ]
    """
    Can create commercial issuing spend cards with Cross River Bank as BIN sponsor.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCard(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCardProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCardProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCardProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankChargeCardProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankPrepaidCard(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankPrepaidCardProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankPrepaidCardProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankPrepaidCardProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankPrepaidCardProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCard(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCardProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCardProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCardProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialCrossRiverBankSpendCardProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThird(
    TypedDict,
):
    charge_card: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThirdChargeCard"
    ]
    """
    Can create commercial issuing charge cards with Fifth Third as BIN sponsor.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThirdChargeCard(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThirdChargeCardProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThirdChargeCardProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThirdChargeCardProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialFifthThirdChargeCardProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialLead(
    TypedDict,
):
    prepaid_card: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCard"
    ]
    """
    Can create commercial issuing prepaid cards with Lead as BIN sponsor.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCard(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCardProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCardProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCardProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialLeadPrepaidCardProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripe(
    TypedDict,
):
    charge_card: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCard"
    ]
    """
    Can create commercial issuing charge cards with Stripe as BIN sponsor.
    """
    prepaid_card: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCard"
    ]
    """
    Can create commercial issuing prepaid cards with Stripe as BIN sponsor.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCard(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCardProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCardProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCardProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripeChargeCardProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCard(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCardProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCardProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCardProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesCommercialStripePrepaidCardProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumer(
    TypedDict,
):
    celtic: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCeltic"
    ]
    """
    Can create consumer issuing cards with Celtic as BIN sponsor.
    """
    cross_river_bank: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBank"
    ]
    """
    Can create consumer issuing cards with Cross River Bank as BIN sponsor.
    """
    lead: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLead"
    ]
    """
    Can create consumer issuing cards with Lead as BIN sponsor.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCeltic(
    TypedDict,
):
    revolving_credit_card: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCelticRevolvingCreditCard"
    ]
    """
    Can create consumer issuing charge cards with Celtic as BIN sponsor.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCelticRevolvingCreditCard(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCelticRevolvingCreditCardProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCelticRevolvingCreditCardProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCelticRevolvingCreditCardProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCelticRevolvingCreditCardProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBank(
    TypedDict,
):
    prepaid_card: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBankPrepaidCard"
    ]
    """
    Can create consumer issuing prepaid cards with Cross River Bank as BIN sponsor.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBankPrepaidCard(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBankPrepaidCardProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBankPrepaidCardProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBankPrepaidCardProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerCrossRiverBankPrepaidCardProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLead(
    TypedDict,
):
    debit_card: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadDebitCard"
    ]
    """
    Can create consumer issuing debit cards with Lead as BIN sponsor.
    """
    prepaid_card: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadPrepaidCard"
    ]
    """
    Can create consumer issuing prepaid cards with Lead as BIN sponsor.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadDebitCard(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadDebitCardProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadDebitCardProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadDebitCardProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadDebitCardProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadPrepaidCard(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadPrepaidCardProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadPrepaidCardProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadPrepaidCardProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationCardCreatorCapabilitiesConsumerLeadPrepaidCardProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationCustomer(TypedDict):
    automatic_indirect_tax: NotRequired[
        "AccountCreateParamsConfigurationCustomerAutomaticIndirectTax"
    ]
    """
    Automatic indirect tax settings to be used when automatic tax calculation is enabled on the customer's invoices, subscriptions, checkout sessions, or payment links. Surfaces if automatic tax calculation is possible given the current customer location information.
    """
    billing: NotRequired["AccountCreateParamsConfigurationCustomerBilling"]
    """
    Billing settings - default settings used for this customer in Billing flows such as Invoices and Subscriptions.
    """
    capabilities: NotRequired[
        "AccountCreateParamsConfigurationCustomerCapabilities"
    ]
    """
    Capabilities that have been requested on the Customer Configuration.
    """
    shipping: NotRequired["AccountCreateParamsConfigurationCustomerShipping"]
    """
    The customer's shipping information. Appears on invoices emailed to this customer.
    """
    test_clock: NotRequired[str]
    """
    ID of the test clock to attach to the customer. Can only be set on testmode Accounts, and when the Customer Configuration is first set on an Account.
    """


class AccountCreateParamsConfigurationCustomerAutomaticIndirectTax(TypedDict):
    exempt: NotRequired[Literal["exempt", "none", "reverse"]]
    """
    Describes the customer's tax exemption status, which is `none`, `exempt`, or `reverse`. When set to reverse, invoice and receipt PDFs include the following text: “Reverse charge”.
    """
    ip_address: NotRequired[str]
    """
    A recent IP address of the customer used for tax reporting and tax location inference.
    """
    location_source: NotRequired[
        Literal[
            "identity_address",
            "ip_address",
            "payment_method",
            "shipping_address",
        ]
    ]
    """
    The data source used to identify the customer's tax location - defaults to `identity_address`. Will only be used for automatic tax calculation on the customer's Invoices and Subscriptions. This behavior is now deprecated for new users.
    """


class AccountCreateParamsConfigurationCustomerBilling(TypedDict):
    invoice: NotRequired[
        "AccountCreateParamsConfigurationCustomerBillingInvoice"
    ]
    """
    Default invoice settings for the customer account.
    """


class AccountCreateParamsConfigurationCustomerBillingInvoice(TypedDict):
    custom_fields: NotRequired[
        List[
            "AccountCreateParamsConfigurationCustomerBillingInvoiceCustomField"
        ]
    ]
    """
    The list of up to 4 default custom fields to be displayed on invoices for this customer.
    """
    footer: NotRequired[str]
    """
    Default invoice footer.
    """
    next_sequence: NotRequired[int]
    """
    Sequence number to use on the customer account's next invoice. Defaults to 1.
    """
    prefix: NotRequired[str]
    """
    Prefix used to generate unique invoice numbers. Must be 3-12 uppercase letters or numbers.
    """
    rendering: NotRequired[
        "AccountCreateParamsConfigurationCustomerBillingInvoiceRendering"
    ]
    """
    Default invoice PDF rendering options.
    """


class AccountCreateParamsConfigurationCustomerBillingInvoiceCustomField(
    TypedDict,
):
    name: str
    """
    The name of the custom field. This may be up to 40 characters.
    """
    value: str
    """
    The value of the custom field. This may be up to 140 characters. When updating, pass an empty string to remove previously-defined values.
    """


class AccountCreateParamsConfigurationCustomerBillingInvoiceRendering(
    TypedDict,
):
    amount_tax_display: NotRequired[
        Literal["exclude_tax", "include_inclusive_tax"]
    ]
    """
    Indicates whether displayed line item prices and amounts on invoice PDFs include inclusive tax amounts. Must be either `include_inclusive_tax` or `exclude_tax`.
    """
    template: NotRequired[str]
    """
    ID of the invoice rendering template to use for future invoices.
    """


class AccountCreateParamsConfigurationCustomerCapabilities(TypedDict):
    automatic_indirect_tax: NotRequired[
        "AccountCreateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax"
    ]
    """
    Generates requirements for enabling automatic indirect tax calculation on this customer's invoices or subscriptions. Recommended to request this capability if planning to enable automatic tax calculation on this customer's invoices or subscriptions.
    """


class AccountCreateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTax(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTaxProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTaxProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTaxProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationCustomerCapabilitiesAutomaticIndirectTaxProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationCustomerShipping(TypedDict):
    address: NotRequired[
        "AccountCreateParamsConfigurationCustomerShippingAddress"
    ]
    """
    Customer shipping address.
    """
    name: NotRequired[str]
    """
    Customer name.
    """
    phone: NotRequired[str]
    """
    Customer phone (including extension).
    """


class AccountCreateParamsConfigurationCustomerShippingAddress(TypedDict):
    city: NotRequired[str]
    """
    City, district, suburb, town, or village.
    """
    country: NotRequired[str]
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired[str]
    """
    Address line 1 (e.g., street, PO Box, or company name).
    """
    line2: NotRequired[str]
    """
    Address line 2 (e.g., apartment, suite, unit, or building).
    """
    postal_code: NotRequired[str]
    """
    ZIP or postal code.
    """
    state: NotRequired[str]
    """
    State, county, province, or region.
    """


class AccountCreateParamsConfigurationMerchant(TypedDict):
    bacs_debit_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantBacsDebitPayments"
    ]
    """
    Settings used for Bacs debit payments.
    """
    branding: NotRequired["AccountCreateParamsConfigurationMerchantBranding"]
    """
    Settings used to apply the merchant's branding to email receipts, invoices, Checkout, and other products.
    """
    capabilities: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilities"
    ]
    """
    Capabilities to request on the Merchant Configuration.
    """
    card_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCardPayments"
    ]
    """
    Card payments settings.
    """
    konbini_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantKonbiniPayments"
    ]
    """
    Settings specific to Konbini payments on the account.
    """
    mcc: NotRequired[str]
    """
    The Merchant Category Code (MCC) for the Merchant Configuration. MCCs classify businesses based on the goods or services they provide.
    """
    script_statement_descriptor: NotRequired[
        "AccountCreateParamsConfigurationMerchantScriptStatementDescriptor"
    ]
    """
    Settings for the default text that appears on statements for language variations.
    """
    smart_disputes: NotRequired[
        "AccountCreateParamsConfigurationMerchantSmartDisputes"
    ]
    """
    Settings used for Smart Disputes.
    """
    statement_descriptor: NotRequired[
        "AccountCreateParamsConfigurationMerchantStatementDescriptor"
    ]
    """
    Statement descriptor.
    """
    support: NotRequired["AccountCreateParamsConfigurationMerchantSupport"]
    """
    Publicly available contact information for sending support issues to.
    """


class AccountCreateParamsConfigurationMerchantBacsDebitPayments(TypedDict):
    display_name: NotRequired[str]
    """
    Display name for Bacs Direct Debit payments.
    """


class AccountCreateParamsConfigurationMerchantBranding(TypedDict):
    icon: NotRequired[str]
    """
    ID of a [file upload](https://docs.stripe.com/api/persons/update#create_file): An icon for the merchant. Must be square and at least 128px x 128px.
    """
    logo: NotRequired[str]
    """
    ID of a [file upload](https://docs.stripe.com/api/persons/update#create_file): A logo for the merchant that will be used in Checkout instead of the icon and without the merchant's name next to it if provided. Must be at least 128px x 128px.
    """
    primary_color: NotRequired[str]
    """
    A CSS hex color value representing the primary branding color for the merchant.
    """
    secondary_color: NotRequired[str]
    """
    A CSS hex color value representing the secondary branding color for the merchant.
    """


class AccountCreateParamsConfigurationMerchantCapabilities(TypedDict):
    ach_debit_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesAchDebitPayments"
    ]
    """
    Allow the merchant to process ACH debit payments.
    """
    acss_debit_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesAcssDebitPayments"
    ]
    """
    Allow the merchant to process ACSS debit payments.
    """
    affirm_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesAffirmPayments"
    ]
    """
    Allow the merchant to process Affirm payments.
    """
    afterpay_clearpay_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments"
    ]
    """
    Allow the merchant to process Afterpay/Clearpay payments.
    """
    alma_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesAlmaPayments"
    ]
    """
    Allow the merchant to process Alma payments.
    """
    amazon_pay_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesAmazonPayPayments"
    ]
    """
    Allow the merchant to process Amazon Pay payments.
    """
    au_becs_debit_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments"
    ]
    """
    Allow the merchant to process Australian BECS Direct Debit payments.
    """
    bacs_debit_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesBacsDebitPayments"
    ]
    """
    Allow the merchant to process BACS Direct Debit payments.
    """
    bancontact_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesBancontactPayments"
    ]
    """
    Allow the merchant to process Bancontact payments.
    """
    blik_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesBlikPayments"
    ]
    """
    Allow the merchant to process BLIK payments.
    """
    boleto_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesBoletoPayments"
    ]
    """
    Allow the merchant to process Boleto payments.
    """
    card_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesCardPayments"
    ]
    """
    Allow the merchant to collect card payments.
    """
    cartes_bancaires_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments"
    ]
    """
    Allow the merchant to process Cartes Bancaires payments.
    """
    cashapp_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesCashappPayments"
    ]
    """
    Allow the merchant to process Cash App payments.
    """
    eps_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesEpsPayments"
    ]
    """
    Allow the merchant to process EPS payments.
    """
    fpx_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesFpxPayments"
    ]
    """
    Allow the merchant to process FPX payments.
    """
    gb_bank_transfer_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments"
    ]
    """
    Allow the merchant to process UK bank transfer payments.
    """
    grabpay_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesGrabpayPayments"
    ]
    """
    Allow the merchant to process GrabPay payments.
    """
    ideal_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesIdealPayments"
    ]
    """
    Allow the merchant to process iDEAL payments.
    """
    jcb_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesJcbPayments"
    ]
    """
    Allow the merchant to process JCB card payments.
    """
    jp_bank_transfer_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments"
    ]
    """
    Allow the merchant to process Japanese bank transfer payments.
    """
    kakao_pay_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesKakaoPayPayments"
    ]
    """
    Allow the merchant to process Kakao Pay payments.
    """
    klarna_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesKlarnaPayments"
    ]
    """
    Allow the merchant to process Klarna payments.
    """
    konbini_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesKonbiniPayments"
    ]
    """
    Allow the merchant to process Konbini convenience store payments.
    """
    kr_card_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesKrCardPayments"
    ]
    """
    Allow the merchant to process Korean card payments.
    """
    link_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesLinkPayments"
    ]
    """
    Allow the merchant to process Link payments.
    """
    mobilepay_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesMobilepayPayments"
    ]
    """
    Allow the merchant to process MobilePay payments.
    """
    multibanco_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesMultibancoPayments"
    ]
    """
    Allow the merchant to process Multibanco payments.
    """
    mx_bank_transfer_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments"
    ]
    """
    Allow the merchant to process Mexican bank transfer payments.
    """
    naver_pay_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesNaverPayPayments"
    ]
    """
    Allow the merchant to process Naver Pay payments.
    """
    oxxo_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesOxxoPayments"
    ]
    """
    Allow the merchant to process OXXO payments.
    """
    p24_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesP24Payments"
    ]
    """
    Allow the merchant to process Przelewy24 (P24) payments.
    """
    pay_by_bank_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesPayByBankPayments"
    ]
    """
    Allow the merchant to process Pay by Bank payments.
    """
    payco_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesPaycoPayments"
    ]
    """
    Allow the merchant to process PAYCO payments.
    """
    paynow_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesPaynowPayments"
    ]
    """
    Allow the merchant to process PayNow payments.
    """
    promptpay_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesPromptpayPayments"
    ]
    """
    Allow the merchant to process PromptPay payments.
    """
    revolut_pay_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesRevolutPayPayments"
    ]
    """
    Allow the merchant to process Revolut Pay payments.
    """
    samsung_pay_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesSamsungPayPayments"
    ]
    """
    Allow the merchant to process Samsung Pay payments.
    """
    sepa_bank_transfer_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments"
    ]
    """
    Allow the merchant to process SEPA bank transfer payments.
    """
    sepa_debit_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesSepaDebitPayments"
    ]
    """
    Allow the merchant to process SEPA Direct Debit payments.
    """
    sunbit_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesSunbitPayments"
    ]
    """
    Allow the merchant to process Sunbit payments.
    """
    swish_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesSwishPayments"
    ]
    """
    Allow the merchant to process Swish payments.
    """
    twint_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesTwintPayments"
    ]
    """
    Allow the merchant to process TWINT payments.
    """
    us_bank_transfer_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments"
    ]
    """
    Allow the merchant to process US bank transfer payments.
    """
    zip_payments: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesZipPayments"
    ]
    """
    Allow the merchant to process Zip payments.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesAchDebitPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesAchDebitPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesAchDebitPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesAchDebitPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesAchDebitPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesAcssDebitPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesAcssDebitPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesAcssDebitPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesAcssDebitPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesAcssDebitPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesAffirmPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesAffirmPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesAffirmPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesAffirmPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesAffirmPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesAfterpayClearpayPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesAlmaPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesAlmaPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesAlmaPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesAlmaPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesAlmaPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesAmazonPayPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesAmazonPayPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesAmazonPayPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesAmazonPayPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesAmazonPayPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesAuBecsDebitPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesAuBecsDebitPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesAuBecsDebitPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesAuBecsDebitPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesAuBecsDebitPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesBacsDebitPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesBacsDebitPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesBacsDebitPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesBacsDebitPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesBacsDebitPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesBancontactPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesBancontactPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesBancontactPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesBancontactPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesBancontactPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesBlikPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesBlikPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesBlikPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesBlikPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesBlikPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesBoletoPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesBoletoPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesBoletoPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesBoletoPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesBoletoPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesCardPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesCardPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesCardPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesCardPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesCardPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesCartesBancairesPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesCartesBancairesPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesCartesBancairesPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesCartesBancairesPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesCartesBancairesPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesCashappPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesCashappPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesCashappPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesCashappPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesCashappPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesEpsPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesEpsPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesEpsPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesEpsPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesEpsPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesFpxPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesFpxPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesFpxPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesFpxPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesFpxPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesGbBankTransferPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesGbBankTransferPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesGbBankTransferPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesGbBankTransferPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesGbBankTransferPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesGrabpayPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesGrabpayPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesGrabpayPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesGrabpayPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesGrabpayPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesIdealPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesIdealPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesIdealPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesIdealPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesIdealPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesJcbPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesJcbPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesJcbPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesJcbPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesJcbPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesJpBankTransferPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesJpBankTransferPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesJpBankTransferPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesJpBankTransferPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesJpBankTransferPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesKakaoPayPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesKakaoPayPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesKakaoPayPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesKakaoPayPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesKakaoPayPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesKlarnaPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesKlarnaPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesKlarnaPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesKlarnaPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesKlarnaPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesKonbiniPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesKonbiniPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesKonbiniPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesKonbiniPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesKonbiniPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesKrCardPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesKrCardPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesKrCardPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesKrCardPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesKrCardPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesLinkPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesLinkPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesLinkPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesLinkPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesLinkPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesMobilepayPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesMobilepayPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesMobilepayPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesMobilepayPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesMobilepayPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesMultibancoPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesMultibancoPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesMultibancoPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesMultibancoPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesMultibancoPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesMxBankTransferPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesMxBankTransferPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesMxBankTransferPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesMxBankTransferPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesMxBankTransferPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesNaverPayPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesNaverPayPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesNaverPayPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesNaverPayPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesNaverPayPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesOxxoPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesOxxoPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesOxxoPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesOxxoPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesOxxoPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesP24Payments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesP24PaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesP24PaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesP24PaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesP24PaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesPayByBankPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesPayByBankPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesPayByBankPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesPayByBankPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesPayByBankPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesPaycoPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesPaycoPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesPaycoPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesPaycoPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesPaycoPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesPaynowPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesPaynowPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesPaynowPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesPaynowPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesPaynowPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesPromptpayPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesPromptpayPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesPromptpayPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesPromptpayPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesPromptpayPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesRevolutPayPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesRevolutPayPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesRevolutPayPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesRevolutPayPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesRevolutPayPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesSamsungPayPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesSamsungPayPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesSamsungPayPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesSamsungPayPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesSamsungPayPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesSepaBankTransferPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesSepaBankTransferPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesSepaBankTransferPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesSepaBankTransferPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesSepaBankTransferPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesSepaDebitPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesSepaDebitPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesSepaDebitPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesSepaDebitPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesSepaDebitPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesSunbitPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesSunbitPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesSunbitPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesSunbitPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesSunbitPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesSwishPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesSwishPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesSwishPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesSwishPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesSwishPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesTwintPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesTwintPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesTwintPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesTwintPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesTwintPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesUsBankTransferPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesUsBankTransferPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesUsBankTransferPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesUsBankTransferPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesUsBankTransferPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesZipPayments(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMerchantCapabilitiesZipPaymentsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesZipPaymentsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMerchantCapabilitiesZipPaymentsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMerchantCapabilitiesZipPaymentsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMerchantCardPayments(TypedDict):
    decline_on: NotRequired[
        "AccountCreateParamsConfigurationMerchantCardPaymentsDeclineOn"
    ]
    """
    Automatically declines certain charge types regardless of whether the card issuer accepted or declined the charge.
    """


class AccountCreateParamsConfigurationMerchantCardPaymentsDeclineOn(TypedDict):
    avs_failure: NotRequired[bool]
    """
    Whether Stripe automatically declines charges with an incorrect ZIP or postal code. This setting only applies when a ZIP or postal code is provided and they fail bank verification.
    """
    cvc_failure: NotRequired[bool]
    """
    Whether Stripe automatically declines charges with an incorrect CVC. This setting only applies when a CVC is provided and it fails bank verification.
    """


class AccountCreateParamsConfigurationMerchantKonbiniPayments(TypedDict):
    support: NotRequired[
        "AccountCreateParamsConfigurationMerchantKonbiniPaymentsSupport"
    ]
    """
    Support for Konbini payments.
    """


class AccountCreateParamsConfigurationMerchantKonbiniPaymentsSupport(
    TypedDict
):
    email: NotRequired[str]
    """
    Support email address for Konbini payments.
    """
    hours: NotRequired[
        "AccountCreateParamsConfigurationMerchantKonbiniPaymentsSupportHours"
    ]
    """
    Support hours for Konbini payments.
    """
    phone: NotRequired[str]
    """
    Support phone number for Konbini payments.
    """


class AccountCreateParamsConfigurationMerchantKonbiniPaymentsSupportHours(
    TypedDict,
):
    end_time: NotRequired[str]
    """
    Support hours end time (JST time of day) for in `HH:MM` format.
    """
    start_time: NotRequired[str]
    """
    Support hours start time (JST time of day) for in `HH:MM` format.
    """


class AccountCreateParamsConfigurationMerchantScriptStatementDescriptor(
    TypedDict,
):
    kana: NotRequired[
        "AccountCreateParamsConfigurationMerchantScriptStatementDescriptorKana"
    ]
    """
    The Kana variation of statement_descriptor used for charges in Japan. Japanese statement descriptors have [special requirements](https://docs.stripe.com/get-started/account/statement-descriptors#set-japanese-statement-descriptors).
    """
    kanji: NotRequired[
        "AccountCreateParamsConfigurationMerchantScriptStatementDescriptorKanji"
    ]
    """
    The Kanji variation of statement_descriptor used for charges in Japan. Japanese statement descriptors have [special requirements](https://docs.stripe.com/get-started/account/statement-descriptors#set-japanese-statement-descriptors).
    """


class AccountCreateParamsConfigurationMerchantScriptStatementDescriptorKana(
    TypedDict,
):
    descriptor: NotRequired[str]
    """
    The default text that appears on statements for non-card charges outside of Japan. For card charges, if you don't set a statement_descriptor_prefix, this text is also used as the statement descriptor prefix. In that case, if concatenating the statement descriptor suffix causes the combined statement descriptor to exceed 22 characters, we truncate the statement_descriptor text to limit the full descriptor to 22 characters. For more information about statement descriptors and their requirements, see the Merchant Configuration settings documentation.
    """
    prefix: NotRequired[str]
    """
    Default text that appears on statements for card charges outside of Japan, prefixing any dynamic statement_descriptor_suffix specified on the charge. To maximize space for the dynamic part of the descriptor, keep this text short. If you don't specify this value, statement_descriptor is used as the prefix. For more information about statement descriptors and their requirements, see the Merchant Configuration settings documentation.
    """


class AccountCreateParamsConfigurationMerchantScriptStatementDescriptorKanji(
    TypedDict,
):
    descriptor: NotRequired[str]
    """
    The default text that appears on statements for non-card charges outside of Japan. For card charges, if you don't set a statement_descriptor_prefix, this text is also used as the statement descriptor prefix. In that case, if concatenating the statement descriptor suffix causes the combined statement descriptor to exceed 22 characters, we truncate the statement_descriptor text to limit the full descriptor to 22 characters. For more information about statement descriptors and their requirements, see the Merchant Configuration settings documentation.
    """
    prefix: NotRequired[str]
    """
    Default text that appears on statements for card charges outside of Japan, prefixing any dynamic statement_descriptor_suffix specified on the charge. To maximize space for the dynamic part of the descriptor, keep this text short. If you don't specify this value, statement_descriptor is used as the prefix. For more information about statement descriptors and their requirements, see the Merchant Configuration settings documentation.
    """


class AccountCreateParamsConfigurationMerchantSmartDisputes(TypedDict):
    auto_respond: NotRequired[
        "AccountCreateParamsConfigurationMerchantSmartDisputesAutoRespond"
    ]
    """
    Settings for Smart Disputes auto_respond.
    """


class AccountCreateParamsConfigurationMerchantSmartDisputesAutoRespond(
    TypedDict,
):
    preference: NotRequired[Literal["inherit", "off", "on"]]
    """
    The preference for Smart Disputes auto-respond.
    """


class AccountCreateParamsConfigurationMerchantStatementDescriptor(TypedDict):
    descriptor: NotRequired[str]
    """
    The default text that appears on statements for non-card charges outside of Japan. For card charges, if you don't set a statement_descriptor_prefix, this text is also used as the statement descriptor prefix. In that case, if concatenating the statement descriptor suffix causes the combined statement descriptor to exceed 22 characters, we truncate the statement_descriptor text to limit the full descriptor to 22 characters. For more information about statement descriptors and their requirements, see the Merchant Configuration settings documentation.
    """
    prefix: NotRequired[str]
    """
    Default text that appears on statements for card charges outside of Japan, prefixing any dynamic statement_descriptor_suffix specified on the charge. To maximize space for the dynamic part of the descriptor, keep this text short. If you don't specify this value, statement_descriptor is used as the prefix. For more information about statement descriptors and their requirements, see the Merchant Configuration settings documentation.
    """


class AccountCreateParamsConfigurationMerchantSupport(TypedDict):
    address: NotRequired[
        "AccountCreateParamsConfigurationMerchantSupportAddress"
    ]
    """
    A publicly available mailing address for sending support issues to.
    """
    email: NotRequired[str]
    """
    A publicly available email address for sending support issues to.
    """
    phone: NotRequired[str]
    """
    A publicly available phone number to call with support issues.
    """
    url: NotRequired[str]
    """
    A publicly available website for handling support issues.
    """


class AccountCreateParamsConfigurationMerchantSupportAddress(TypedDict):
    city: NotRequired[str]
    """
    City, district, suburb, town, or village.
    """
    country: str
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired[str]
    """
    Address line 1 (e.g., street, PO Box, or company name).
    """
    line2: NotRequired[str]
    """
    Address line 2 (e.g., apartment, suite, unit, or building).
    """
    postal_code: NotRequired[str]
    """
    ZIP or postal code.
    """
    state: NotRequired[str]
    """
    State, county, province, or region.
    """
    town: NotRequired[str]
    """
    Town or district.
    """


class AccountCreateParamsConfigurationMoneyManager(TypedDict):
    capabilities: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilities"
    ]
    """
    Capabilities to request on the Money Manager Configuration.
    """
    high_risk_activities: NotRequired[
        List[
            Literal[
                "adult_entertainment",
                "gambling",
                "hold_client_funds",
                "investment_services",
                "lending_banking",
                "marijuana_or_related_services",
                "money_services",
                "nicotine_tobacco_or_related_services",
                "none",
                "operate_foreign_exchange_virtual_currencies_brokerage_otc",
                "pharmaceuticals",
                "precious_metals_precious_stones_jewelry",
                "safe_deposit_box_rentals",
                "third_party_payment_processing",
                "weapons_firearms_and_explosives",
            ]
        ]
    ]
    """
    List of high-risk activities the business is involved in.
    """
    high_risk_activities_description: NotRequired[str]
    """
    Description of the high-risk activities the business offers.
    """
    money_services_description: NotRequired[str]
    """
    Description of the money services offered by the business.
    """
    operates_in_prohibited_countries: NotRequired[bool]
    """
    Indicates whether the business operates in any prohibited countries.
    """
    participates_in_regulated_activity: NotRequired[bool]
    """
    Indicates whether the business participates in any regulated activity.
    """
    purpose_of_funds: NotRequired[
        Literal[
            "charitable_donations",
            "ecommerce_retail_payments",
            "investment_purposes",
            "other",
            "payments_to_friends_or_family_abroad",
            "payroll",
            "personal_or_living_expenses",
            "protect_wealth",
            "purchase_goods_and_services",
            "receive_payments_for_goods_and_services",
            "tax_optimization",
            "third_party_money_transmission",
            "treasury_management",
        ]
    ]
    """
    Primary purpose of the stored funds.
    """
    purpose_of_funds_description: NotRequired[str]
    """
    Description of the purpose of the stored funds.
    """
    regulated_activity: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerRegulatedActivity"
    ]
    """
    Details of the regulated activity if the business participates in one.
    """
    source_of_funds: NotRequired[
        Literal[
            "business_loans",
            "grants",
            "inter_company_funds",
            "investment_proceeds",
            "legal_settlement",
            "owners_capital",
            "pension_retirement",
            "sales_of_assets",
            "sales_of_goods_and_services",
            "tax_refund",
            "third_party_funds",
            "treasury_reserves",
        ]
    ]
    """
    The source of funds for the business, e.g. profits, income, venture capital, etc.
    """
    source_of_funds_description: NotRequired[str]
    """
    Description of the source of funds for the business' account.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilities(TypedDict):
    business_storage: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorage"
    ]
    """
    Can send or receive business storage-type funds on Stripe.
    """
    consumer_storage: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorage"
    ]
    """
    Can send or receive consumer storage-type funds on Stripe.
    """
    inbound_transfers: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesInboundTransfers"
    ]
    """
    Can pull funds from an external source, owned by yourself, to a FinancialAccount.
    """
    outbound_payments: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPayments"
    ]
    """
    Can send funds from a FinancialAccount to a destination owned by someone else.
    """
    outbound_transfers: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfers"
    ]
    """
    Can send funds from a FinancialAccount to a destination owned by yourself.
    """
    received_credits: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCredits"
    ]
    """
    Can receive funds into a FinancialAccount.
    """
    received_debits: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedDebits"
    ]
    """
    Can receive debits to a FinancialAccount.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorage(
    TypedDict,
):
    inbound: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInbound"
    ]
    """
    Can receive business storage-type funds on Stripe.
    """
    outbound: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutbound"
    ]
    """
    Can send business storage-type funds on Stripe.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInbound(
    TypedDict,
):
    aud: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundAud"
    ]
    """
    Can receive business storage-type funds on Stripe in AUD.
    """
    cad: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundCad"
    ]
    """
    Can receive business storage-type funds on Stripe in CAD.
    """
    eur: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundEur"
    ]
    """
    Can receive business storage-type funds on Stripe in EUR.
    """
    gbp: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundGbp"
    ]
    """
    Can receive business storage-type funds on Stripe in GBP.
    """
    usd: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsd"
    ]
    """
    Can receive business storage-type funds on Stripe in USD.
    """
    usdc: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdc"
    ]
    """
    Can receive business storage-type funds on Stripe in USDC.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundAud(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundAudProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundAudProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundAudProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundAudProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundCad(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundCadProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundCadProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundCadProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundCadProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundEur(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundEurProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundEurProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundEurProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundEurProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundGbp(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundGbpProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundGbpProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundGbpProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundGbpProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsd(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdc(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdcProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdcProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdcProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageInboundUsdcProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutbound(
    TypedDict,
):
    aud: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundAud"
    ]
    """
    Can send business storage-type funds on Stripe in AUD.
    """
    cad: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundCad"
    ]
    """
    Can send business storage-type funds on Stripe in CAD.
    """
    eur: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundEur"
    ]
    """
    Can send business storage-type funds on Stripe in EUR.
    """
    gbp: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundGbp"
    ]
    """
    Can send business storage-type funds on Stripe in GBP.
    """
    usd: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsd"
    ]
    """
    Can send business storage-type funds on Stripe in USD.
    """
    usdc: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdc"
    ]
    """
    Can send business storage-type funds on Stripe in USDC.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundAud(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundAudProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundAudProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundAudProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundAudProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundCad(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundCadProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundCadProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundCadProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundCadProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundEur(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundEurProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundEurProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundEurProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundEurProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundGbp(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundGbpProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundGbpProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundGbpProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundGbpProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsd(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdc(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdcProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdcProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdcProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesBusinessStorageOutboundUsdcProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorage(
    TypedDict,
):
    inbound: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInbound"
    ]
    """
    Can receive consumer storage-type funds on Stripe.
    """
    outbound: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutbound"
    ]
    """
    Can send consumer storage-type funds on Stripe.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInbound(
    TypedDict,
):
    usd: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsd"
    ]
    """
    Can receive consumer storage-type funds on Stripe in USD.
    """
    usdc: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdc"
    ]
    """
    Can receive consumer storage-type funds on Stripe in USDC.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsd(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdc(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdcProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdcProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdcProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageInboundUsdcProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutbound(
    TypedDict,
):
    usd: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsd"
    ]
    """
    Can send consumer storage-type funds on Stripe in USD.
    """
    usdc: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdc"
    ]
    """
    Can send consumer storage-type funds on Stripe in USDC.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsd(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdc(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdcProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdcProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdcProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesConsumerStorageOutboundUsdcProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesInboundTransfers(
    TypedDict,
):
    bank_accounts: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesInboundTransfersBankAccounts"
    ]
    """
    Can pull funds from an external bank account owned by yourself to a FinancialAccount.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesInboundTransfersBankAccounts(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesInboundTransfersBankAccountsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesInboundTransfersBankAccountsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMoneyManagerCapabilitiesInboundTransfersBankAccountsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesInboundTransfersBankAccountsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPayments(
    TypedDict,
):
    bank_accounts: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsBankAccounts"
    ]
    """
    Can send funds from a FinancialAccount to a bank account owned by someone else.
    """
    cards: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCards"
    ]
    """
    Can send funds from a FinancialAccount to a debit card owned by someone else.
    """
    crypto_wallets: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCryptoWallets"
    ]
    """
    Can send funds from a FinancialAccount to a crypto wallet owned by someone else.
    """
    financial_accounts: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsFinancialAccounts"
    ]
    """
    Can send funds from a FinancialAccount to another FinancialAccount owned by someone else.
    """
    paper_checks: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsPaperChecks"
    ]
    """
    Can send funds from a FinancialAccount to someone else via paper check.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsBankAccounts(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsBankAccountsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsBankAccountsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsBankAccountsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsBankAccountsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCards(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCardsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCardsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCardsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCardsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCryptoWallets(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCryptoWalletsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCryptoWalletsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCryptoWalletsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsCryptoWalletsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsFinancialAccounts(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsFinancialAccountsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsFinancialAccountsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsFinancialAccountsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsFinancialAccountsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsPaperChecks(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsPaperChecksProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsPaperChecksProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsPaperChecksProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundPaymentsPaperChecksProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfers(
    TypedDict,
):
    bank_accounts: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersBankAccounts"
    ]
    """
    Can send funds from a FinancialAccount to a bank account owned by yourself.
    """
    crypto_wallets: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersCryptoWallets"
    ]
    """
    Can send funds from a FinancialAccount to a crypto wallet owned by yourself.
    """
    financial_accounts: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersFinancialAccounts"
    ]
    """
    Can send funds from a FinancialAccount to another FinancialAccount owned by yourself.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersBankAccounts(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersBankAccountsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersBankAccountsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersBankAccountsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersBankAccountsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersCryptoWallets(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersCryptoWalletsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersCryptoWalletsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersCryptoWalletsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersCryptoWalletsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersFinancialAccounts(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersFinancialAccountsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersFinancialAccountsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersFinancialAccountsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesOutboundTransfersFinancialAccountsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCredits(
    TypedDict,
):
    bank_accounts: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsBankAccounts"
    ]
    """
    Can receive funds on a bank-account-like financial address (VBAN) to credit a FinancialAccount.
    """
    crypto_wallets: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsCryptoWallets"
    ]
    """
    Can receive funds on a crypto wallet like financial address to credit a FinancialAccount.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsBankAccounts(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsBankAccountsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsBankAccountsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsBankAccountsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsBankAccountsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsCryptoWallets(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsCryptoWalletsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsCryptoWalletsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsCryptoWalletsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedCreditsCryptoWalletsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedDebits(
    TypedDict,
):
    bank_accounts: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedDebitsBankAccounts"
    ]
    """
    Can receive debits to a FinancialAccount from a bank account.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedDebitsBankAccounts(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedDebitsBankAccountsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedDebitsBankAccountsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedDebitsBankAccountsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationMoneyManagerCapabilitiesReceivedDebitsBankAccountsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationMoneyManagerRegulatedActivity(TypedDict):
    description: NotRequired[str]
    """
    A detailed description of the regulated activities the business is licensed to conduct.
    """
    license_number: NotRequired[str]
    """
    The license number or registration number assigned by the business's primary regulator.
    """
    primary_regulatory_authority_country: NotRequired[str]
    """
    The country of the primary regulatory authority that oversees the business's regulated activities.
    """
    primary_regulatory_authority_name: NotRequired[str]
    """
    The name of the primary regulatory authority that oversees the business's regulated activities.
    """


class AccountCreateParamsConfigurationRecipient(TypedDict):
    capabilities: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilities"
    ]
    """
    Capabilities to be requested on the Recipient Configuration.
    """


class AccountCreateParamsConfigurationRecipientCapabilities(TypedDict):
    bank_accounts: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccounts"
    ]
    """
    Capabilities that enable OutboundPayments to a bank account linked to this Account.
    """
    cards: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesCards"
    ]
    """
    Capabilities that enable OutboundPayments to a card linked to this Account.
    """
    crypto_wallets: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesCryptoWallets"
    ]
    """
    Capabilities that enable OutboundPayments to a crypto wallet linked to this Account.
    """
    paper_checks: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesPaperChecks"
    ]
    """
    Capabilities that enable OutboundPayments via paper check.
    """
    stripe_balance: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalance"
    ]
    """
    Capabilities that enable the recipient to manage their Stripe Balance (/v1/balance).
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccounts(
    TypedDict,
):
    ach: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsAch"
    ]
    """
    Enables this Account to receive OutboundPayments to linked bank accounts over ACH rails.
    """
    becs: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsBecs"
    ]
    """
    Enables this Account to receive OutboundPayments to linked bank accounts over BECS rails.
    """
    eft: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsEft"
    ]
    """
    Enables this Account to receive OutboundPayments to linked bank accounts over EFT rails.
    """
    fedwire: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFedwire"
    ]
    """
    Enables this Account to receive OutboundPayments to linked bank accounts over Fedwire or CHIPS.
    """
    fps: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFps"
    ]
    """
    Enables this Account to receive OutboundPayments to linked bank accounts over FPS rails.
    """
    instant: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsInstant"
    ]
    """
    Enables this Account to receive OutboundPayments to linked bank accounts over real time rails.
    """
    local: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsLocal"
    ]
    """
    Enables this Account to receive OutboundPayments to linked bank accounts over local networks.
    """
    npp: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsNpp"
    ]
    """
    Enables this Account to receive OutboundPayments to linked bank accounts over NPP (real time) rails.
    """
    rtp: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsRtp"
    ]
    """
    Enables this Account to receive OutboundPayments to linked bank accounts over RTP rails.
    """
    sepa_credit: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaCredit"
    ]
    """
    Enables this Account to receive OutboundPayments to linked bank accounts over SEPA credit rails.
    """
    sepa_instant: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaInstant"
    ]
    """
    Enables this Account to receive OutboundPayments to linked bank accounts over SEPA instant (real time) rails.
    """
    swift: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSwift"
    ]
    """
    Enables this Account to receive OutboundPayments to linked bank accounts over SWIFT.
    """
    wire: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsWire"
    ]
    """
    Enables this Account to receive OutboundPayments to linked bank accounts over wire.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsAch(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsAchProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsAchProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsAchProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsAchProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsBecs(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsBecsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsBecsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsBecsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsBecsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsEft(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsEftProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsEftProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsEftProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsEftProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFedwire(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFedwireProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFedwireProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFedwireProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFedwireProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFps(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFpsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFpsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFpsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsFpsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsInstant(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsInstantProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsInstantProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsInstantProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsInstantProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsLocal(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsLocalProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsLocalProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsLocalProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsLocalProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsNpp(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsNppProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsNppProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsNppProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsNppProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsRtp(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsRtpProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsRtpProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsRtpProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsRtpProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaCredit(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaCreditProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaCreditProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaCreditProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaCreditProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaInstant(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaInstantProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaInstantProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaInstantProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSepaInstantProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSwift(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSwiftProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSwiftProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSwiftProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsSwiftProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsWire(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsWireProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsWireProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsWireProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesBankAccountsWireProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesCards(TypedDict):
    protections: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesCardsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesCardsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationRecipientCapabilitiesCardsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesCardsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesCryptoWallets(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesCryptoWalletsProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesCryptoWalletsProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationRecipientCapabilitiesCryptoWalletsProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesCryptoWalletsProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesPaperChecks(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesPaperChecksProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesPaperChecksProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationRecipientCapabilitiesPaperChecksProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesPaperChecksProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalance(
    TypedDict,
):
    stripe_transfers: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers"
    ]
    """
    Enables this Account to receive /v1/transfers into their Stripe Balance (/v1/balance).
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfers(
    TypedDict,
):
    protections: NotRequired[
        "AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfersProtections"
    ]
    """
    Protection types to request for this capability (e.g. "psp_migration").
    """
    requested: bool
    """
    To request a new Capability for an account, pass true. There can be a delay before the requested Capability becomes active.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfersProtections(
    TypedDict,
):
    psp_migration: "AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfersProtectionsPspMigration"
    """
    Parameter to request psp_migration protection.
    """


class AccountCreateParamsConfigurationRecipientCapabilitiesStripeBalanceStripeTransfersProtectionsPspMigration(
    TypedDict,
):
    requested: bool
    """
    To request a protection, pass true.
    """


class AccountCreateParamsDefaults(TypedDict):
    currency: NotRequired[str]
    """
    Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).
    """
    locales: NotRequired[
        List[
            Literal[
                "ar-SA",
                "bg",
                "bg-BG",
                "cs",
                "cs-CZ",
                "da",
                "da-DK",
                "de",
                "de-DE",
                "el",
                "el-GR",
                "en",
                "en-AU",
                "en-CA",
                "en-GB",
                "en-IE",
                "en-IN",
                "en-NZ",
                "en-SG",
                "en-US",
                "es",
                "es-419",
                "es-ES",
                "et",
                "et-EE",
                "fi",
                "fil",
                "fil-PH",
                "fi-FI",
                "fr",
                "fr-CA",
                "fr-FR",
                "he-IL",
                "hr",
                "hr-HR",
                "hu",
                "hu-HU",
                "id",
                "id-ID",
                "it",
                "it-IT",
                "ja",
                "ja-JP",
                "ko",
                "ko-KR",
                "lt",
                "lt-LT",
                "lv",
                "lv-LV",
                "ms",
                "ms-MY",
                "mt",
                "mt-MT",
                "nb",
                "nb-NO",
                "nl",
                "nl-NL",
                "pl",
                "pl-PL",
                "pt",
                "pt-BR",
                "pt-PT",
                "ro",
                "ro-RO",
                "ru",
                "ru-RU",
                "sk",
                "sk-SK",
                "sl",
                "sl-SI",
                "sv",
                "sv-SE",
                "th",
                "th-TH",
                "tr",
                "tr-TR",
                "vi",
                "vi-VN",
                "zh",
                "zh-Hans",
                "zh-Hant-HK",
                "zh-Hant-TW",
                "zh-HK",
                "zh-TW",
            ]
        ]
    ]
    """
    The Account's preferred locales (languages), ordered by preference.
    """
    profile: NotRequired["AccountCreateParamsDefaultsProfile"]
    """
    Account profile information.
    """
    responsibilities: NotRequired[
        "AccountCreateParamsDefaultsResponsibilities"
    ]
    """
    Default responsibilities held by either Stripe or the platform.
    """
    timezone: NotRequired[str]
    """
    The Account's local timezone. A list of possible time zone values is maintained at the [IANA Time Zone Database](https://www.iana.org/time-zones).
    """


class AccountCreateParamsDefaultsProfile(TypedDict):
    business_url: NotRequired[str]
    """
    The business's publicly-available website.
    """
    doing_business_as: NotRequired[str]
    """
    The name which is used by the business.
    """
    product_description: NotRequired[str]
    """
    Internal-only description of the product sold or service provided by the business. It's used by Stripe for risk and underwriting purposes.
    """


class AccountCreateParamsDefaultsResponsibilities(TypedDict):
    fees_collector: Literal[
        "application", "application_custom", "application_express", "stripe"
    ]
    """
    A value indicating the party responsible for collecting fees from this account.
    """
    losses_collector: Literal["application", "stripe"]
    """
    A value indicating who is responsible for losses when this Account can't pay back negative balances from payments.
    """
    requirements_collector: NotRequired[Literal["application", "stripe"]]
    """
    A value indicating the party responsible for collecting requirements on this account.
    """


class AccountCreateParamsIdentity(TypedDict):
    attestations: NotRequired["AccountCreateParamsIdentityAttestations"]
    """
    Attestations from the identity's key people, e.g. owners, executives, directors, representatives.
    """
    business_details: NotRequired["AccountCreateParamsIdentityBusinessDetails"]
    """
    Information about the company or business.
    """
    country: NotRequired[str]
    """
    The country in which the account holder resides, or in which the business is legally established. This should be an [ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code.
    """
    entity_type: NotRequired[
        Literal["company", "government_entity", "individual", "non_profit"]
    ]
    """
    The entity type represented by the Account. Ensure this field is accurate before adding configurations that rely on identity information, as it determines which identity fields apply and how the Account is validated.
    """
    individual: NotRequired["AccountCreateParamsIdentityIndividual"]
    """
    Information about the person represented by the account.
    """


class AccountCreateParamsIdentityAttestations(TypedDict):
    directorship_declaration: NotRequired[
        "AccountCreateParamsIdentityAttestationsDirectorshipDeclaration"
    ]
    """
    This hash is used to attest that the directors information provided to Stripe is both current and correct.
    """
    ownership_declaration: NotRequired[
        "AccountCreateParamsIdentityAttestationsOwnershipDeclaration"
    ]
    """
    This hash is used to attest that the beneficial owner information provided to Stripe is both current and correct.
    """
    persons_provided: NotRequired[
        "AccountCreateParamsIdentityAttestationsPersonsProvided"
    ]
    """
    Attestation that all Persons with a specific Relationship value have been provided.
    """
    representative_declaration: NotRequired[
        "AccountCreateParamsIdentityAttestationsRepresentativeDeclaration"
    ]
    """
    This hash is used to attest that the representative is authorized to act as the representative of their legal entity.
    """
    terms_of_service: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfService"
    ]
    """
    Attestations of accepted terms of service agreements.
    """


class AccountCreateParamsIdentityAttestationsDirectorshipDeclaration(
    TypedDict
):
    date: NotRequired[str]
    """
    The time marking when the director attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: NotRequired[str]
    """
    The IP address from which the director attestation was made.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the director attestation was made.
    """


class AccountCreateParamsIdentityAttestationsOwnershipDeclaration(TypedDict):
    date: NotRequired[str]
    """
    The time marking when the beneficial owner attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: NotRequired[str]
    """
    The IP address from which the beneficial owner attestation was made.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the beneficial owner attestation was made.
    """


class AccountCreateParamsIdentityAttestationsPersonsProvided(TypedDict):
    directors: NotRequired[bool]
    """
    Whether the company's directors have been provided. Set this Boolean to true after creating all the company's directors with the [Persons API](https://docs.stripe.com/api/v2/core/accounts/createperson).
    """
    executives: NotRequired[bool]
    """
    Whether the company's executives have been provided. Set this Boolean to true after creating all the company's executives with the [Persons API](https://docs.stripe.com/api/v2/core/accounts/createperson).
    """
    owners: NotRequired[bool]
    """
    Whether the company's owners have been provided. Set this Boolean to true after creating all the company's owners with the [Persons API](https://docs.stripe.com/api/v2/core/accounts/createperson).
    """
    ownership_exemption_reason: NotRequired[
        Literal[
            "qualified_entity_exceeds_ownership_threshold",
            "qualifies_as_financial_institution",
        ]
    ]
    """
    Reason for why the company is exempt from providing ownership information.
    """


class AccountCreateParamsIdentityAttestationsRepresentativeDeclaration(
    TypedDict,
):
    date: NotRequired[str]
    """
    The time marking when the representative attestation was made. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: NotRequired[str]
    """
    The IP address from which the representative attestation was made.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the representative attestation was made.
    """


class AccountCreateParamsIdentityAttestationsTermsOfService(TypedDict):
    account: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceAccount"
    ]
    """
    Details on the Account's acceptance of the [Stripe Services Agreement](https://docs.stripe.com/connect/updating-accounts#tos-acceptance).
    """
    card_creator: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreator"
    ]
    """
    Details on the Account's acceptance of Issuing-specific terms of service.
    """
    consumer_money_manager: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceConsumerMoneyManager"
    ]
    """
    Details on the Account's acceptance of Consumer-specific terms of service.
    """
    consumer_privacy_disclosures: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceConsumerPrivacyDisclosures"
    ]
    """
    Details on the Account's acceptance of Consumer-privacy-disclosures-specific terms of service.
    """
    crypto_money_manager: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCryptoMoneyManager"
    ]
    """
    Details on the Account's acceptance of Crypto-specific terms of service.
    """
    money_manager: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceMoneyManager"
    ]
    """
    Details on the Account's acceptance of Treasury-specific terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceAccount(TypedDict):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreator(
    TypedDict,
):
    commercial: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercial"
    ]
    """
    Terms of service acceptances to create cards for commercial issuing use cases.
    """
    consumer: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumer"
    ]
    """
    Terms of service acceptances to create cards for consumer issuing use cases.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercial(
    TypedDict,
):
    account_holder: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialAccountHolder"
    ]
    """
    Terms of service acceptances for Stripe commercial card issuing.
    """
    celtic: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCeltic"
    ]
    """
    Terms of service acceptances for commercial issuing cards with Celtic as BIN sponsor.
    """
    cross_river_bank: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBank"
    ]
    """
    Terms of service acceptances for commercial issuing cards with Cross River Bank as BIN sponsor.
    """
    fifth_third: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThird"
    ]
    """
    Terms of service acceptances for commercial issuing cards with Fifth Third as BIN sponsor.
    """
    global_account_holder: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialGlobalAccountHolder"
    ]
    """
    Terms of service acceptances for Stripe commercial card Global issuing.
    """
    lead: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLead"
    ]
    """
    Terms of service acceptances for commercial issuing cards with Lead as BIN sponsor.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialAccountHolder(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCeltic(
    TypedDict,
):
    apple_pay: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticApplePay"
    ]
    """
    Terms of service acceptances for commercial issuing Apple Pay cards with Celtic as BIN sponsor.
    """
    charge_card: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCard"
    ]
    """
    Terms of service acceptances for commercial issuing charge cards with Celtic as BIN sponsor.
    """
    spend_card: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCard"
    ]
    """
    Terms of service acceptances for commercial issuing spend cards with Celtic as BIN sponsor.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticApplePay(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCard(
    TypedDict,
):
    bank_terms: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardBankTerms"
    ]
    """
    Bank terms of service acceptance for commercial issuing charge cards with Celtic as BIN sponsor.
    """
    platform: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardPlatform"
    ]
    """
    Platform terms of service acceptance for commercial issuing charge cards with Celtic as BIN sponsor.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardBankTerms(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticChargeCardPlatform(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCard(
    TypedDict,
):
    bank_terms: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardBankTerms"
    ]
    """
    Bank terms of service acceptance for commercial issuing spend cards with Celtic as BIN sponsor.
    """
    financing_disclosures: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardFinancingDisclosures"
    ]
    """
    Financial disclosures terms of service acceptance for commercial issuing spend cards with Celtic as BIN sponsor.
    """
    platform: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardPlatform"
    ]
    """
    Platform terms of service acceptance for commercial issuing spend cards with Celtic as BIN sponsor.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardBankTerms(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardFinancingDisclosures(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCelticSpendCardPlatform(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBank(
    TypedDict,
):
    apple_pay: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankApplePay"
    ]
    """
    Terms of service acceptances for commercial issuing Apple Pay cards with Cross River Bank as BIN sponsor.
    """
    charge_card: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCard"
    ]
    """
    Terms of service acceptances for commercial issuing charge cards with Cross River Bank as BIN sponsor.
    """
    prepaid_card: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankPrepaidCard"
    ]
    """
    Terms of service acceptances for commercial issuing prepaid cards with Cross River Bank as BIN sponsor.
    """
    spend_card: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCard"
    ]
    """
    Terms of service acceptances for commercial issuing spend cards with Cross River Bank as BIN sponsor.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankApplePay(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCard(
    TypedDict,
):
    bank_terms: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardBankTerms"
    ]
    """
    Bank terms of service acceptance for commercial issuing charge cards with Cross River Bank as BIN sponsor.
    """
    financing_disclosures: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardFinancingDisclosures"
    ]
    """
    Financial disclosures terms of service acceptance for commercial issuing charge cards with Cross River Bank as BIN sponsor.
    """
    platform: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardPlatform"
    ]
    """
    Platform terms of service acceptance for commercial issuing charge cards with Cross River Bank as BIN sponsor.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardBankTerms(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardFinancingDisclosures(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankChargeCardPlatform(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankPrepaidCard(
    TypedDict,
):
    bank_terms: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankPrepaidCardBankTerms"
    ]
    """
    Bank terms of service acceptance for commercial issuing prepaid cards with Cross River Bank as BIN sponsor.
    """
    platform: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankPrepaidCardPlatform"
    ]
    """
    Platform terms of service acceptance for commercial issuing prepaid cards with Cross River Bank as BIN sponsor.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankPrepaidCardBankTerms(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankPrepaidCardPlatform(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCard(
    TypedDict,
):
    bank_terms: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardBankTerms"
    ]
    """
    Bank terms of service acceptance for commercial issuing spend cards with Cross River Bank as BIN sponsor.
    """
    financing_disclosures: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardFinancingDisclosures"
    ]
    """
    Financial disclosures terms of service acceptance for commercial issuing spend cards with Cross River Bank as BIN sponsor.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardBankTerms(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialCrossRiverBankSpendCardFinancingDisclosures(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThird(
    TypedDict,
):
    apple_pay: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdApplePay"
    ]
    """
    Terms of service acceptances for commercial issuing Apple Pay cards with Fifth Third as BIN sponsor.
    """
    charge_card: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCard"
    ]
    """
    Terms of service acceptances for commercial issuing charge cards with Fifth Third as BIN sponsor.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdApplePay(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCard(
    TypedDict,
):
    bank_terms: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCardBankTerms"
    ]
    """
    Bank terms of service acceptance for commercial issuing charge cards with Fifth Third as BIN sponsor.
    """
    financing_disclosures: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCardFinancingDisclosures"
    ]
    """
    Financial disclosures terms of service acceptance for commercial issuing charge cards with Fifth Third as BIN sponsor.
    """
    platform: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCardPlatform"
    ]
    """
    Platform terms of service acceptance for commercial issuing charge cards with Fifth Third as BIN sponsor.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCardBankTerms(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCardFinancingDisclosures(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialFifthThirdChargeCardPlatform(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialGlobalAccountHolder(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLead(
    TypedDict,
):
    apple_pay: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadApplePay"
    ]
    """
    Terms of service acceptances for commercial issuing Apple Pay cards with Lead as BIN sponsor.
    """
    prepaid_card: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCard"
    ]
    """
    Terms of service acceptances for commercial issuing prepaid cards with Lead as BIN sponsor.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadApplePay(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCard(
    TypedDict,
):
    bank_terms: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCardBankTerms"
    ]
    """
    Bank terms of service acceptance for commercial issuing prepaid cards with Lead as BIN sponsor.
    """
    platform: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCardPlatform"
    ]
    """
    Platform terms of service acceptance for commercial issuing prepaid cards with Lead as BIN sponsor.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCardBankTerms(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorCommercialLeadPrepaidCardPlatform(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumer(
    TypedDict,
):
    account_holder: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerAccountHolder"
    ]
    """
    Terms of service acceptances for Stripe consumer card issuing.
    """
    celtic: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCeltic"
    ]
    """
    Terms of service acceptances for consumer issuing cards with Celtic as BIN sponsor.
    """
    cross_river_bank: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBank"
    ]
    """
    Terms of service acceptances for consumer issuing cards with Cross River Bank as BIN sponsor.
    """
    global_account_holder: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerGlobalAccountHolder"
    ]
    """
    Terms of service acceptances for Stripe consumer card Global issuing.
    """
    lead: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLead"
    ]
    """
    Terms of service acceptances for consumer issuing cards with Lead as BIN sponsor.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerAccountHolder(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCeltic(
    TypedDict,
):
    apple_pay: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticApplePay"
    ]
    """
    Terms of service acceptances for consumer issuing Apple Pay cards with Celtic as BIN sponsor.
    """
    revolving_credit_card: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCard"
    ]
    """
    Terms of service acceptances for consumer issuing charge cards with Celtic as BIN sponsor.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticApplePay(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCard(
    TypedDict,
):
    bank_terms: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCardBankTerms"
    ]
    """
    Bank terms of service acceptance for consumer issuing spend cards with Celtic as BIN sponsor.
    """
    financing_disclosures: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCardFinancingDisclosures"
    ]
    """
    Financial disclosures terms of service acceptance for consumer issuing spend cards with Celtic as BIN sponsor.
    """
    platform: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCardPlatform"
    ]
    """
    Platform terms of service acceptance for consumer issuing spend cards with Celtic as BIN sponsor.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCardBankTerms(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCardFinancingDisclosures(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCelticRevolvingCreditCardPlatform(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBank(
    TypedDict,
):
    prepaid_card: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCard"
    ]
    """
    Terms of service acceptances for consumer issuing prepaid cards with Cross River Bank as BIN sponsor.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCard(
    TypedDict,
):
    bank_terms: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCardBankTerms"
    ]
    """
    Bank terms of service acceptance for consumer issuing prepaid cards with Cross River Bank as BIN sponsor.
    """
    financing_disclosures: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCardFinancingDisclosures"
    ]
    """
    Financial disclosures terms of service acceptance for consumer issuing prepaid cards with Cross River Bank as BIN sponsor.
    """
    platform: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCardPlatform"
    ]
    """
    Platform terms of service acceptance for consumer issuing prepaid cards with Cross River Bank as BIN sponsor.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCardBankTerms(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCardFinancingDisclosures(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerCrossRiverBankPrepaidCardPlatform(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerGlobalAccountHolder(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLead(
    TypedDict,
):
    debit_card: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCard"
    ]
    """
    Terms of service acceptances for consumer issuing debit cards with Lead as BIN sponsor.
    """
    prepaid_card: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCard"
    ]
    """
    Terms of service acceptances for consumer issuing prepaid cards with Lead as BIN sponsor.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCard(
    TypedDict,
):
    bank_terms: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCardBankTerms"
    ]
    """
    Bank terms of service acceptance for consumer issuing debit cards with Lead as BIN sponsor.
    """
    financing_disclosures: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCardFinancingDisclosures"
    ]
    """
    Financial disclosures terms of service acceptance for consumer issuing debit cards with Lead as BIN sponsor.
    """
    platform: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCardPlatform"
    ]
    """
    Platform terms of service acceptance for consumer issuing debit cards with Lead as BIN sponsor.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCardBankTerms(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCardFinancingDisclosures(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadDebitCardPlatform(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCard(
    TypedDict,
):
    bank_terms: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCardBankTerms"
    ]
    """
    Bank terms of service acceptance for consumer issuing prepaid cards with Lead as BIN sponsor.
    """
    financing_disclosures: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCardFinancingDisclosures"
    ]
    """
    Financial disclosures terms of service acceptance for consumer issuing prepaid cards with Lead as BIN sponsor.
    """
    platform: NotRequired[
        "AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCardPlatform"
    ]
    """
    Platform terms of service acceptance for consumer issuing prepaid cards with Lead as BIN sponsor.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCardBankTerms(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCardFinancingDisclosures(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCardCreatorConsumerLeadPrepaidCardPlatform(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceConsumerMoneyManager(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceConsumerPrivacyDisclosures(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceCryptoMoneyManager(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityAttestationsTermsOfServiceMoneyManager(
    TypedDict,
):
    date: str
    """
    The time when the Account's representative accepted the terms of service. Represented as a RFC 3339 date & time UTC value in millisecond precision, for example: 2022-09-18T13:22:18.123Z.
    """
    ip: str
    """
    The IP address from which the Account's representative accepted the terms of service.
    """
    user_agent: NotRequired[str]
    """
    The user agent of the browser from which the Account's representative accepted the terms of service.
    """


class AccountCreateParamsIdentityBusinessDetails(TypedDict):
    address: NotRequired["AccountCreateParamsIdentityBusinessDetailsAddress"]
    """
    The business registration address of the business entity.
    """
    annual_revenue: NotRequired[
        "AccountCreateParamsIdentityBusinessDetailsAnnualRevenue"
    ]
    """
    The business gross annual revenue for its preceding fiscal year.
    """
    compliance_screening_description: NotRequired[str]
    """
    A detailed description of the business's compliance and anti-money laundering controls and practices.
    """
    documents: NotRequired[
        "AccountCreateParamsIdentityBusinessDetailsDocuments"
    ]
    """
    A document verifying the business.
    """
    estimated_worker_count: NotRequired[int]
    """
    Estimated maximum number of workers currently engaged by the business (including employees, contractors, and vendors).
    """
    id_numbers: NotRequired[
        List["AccountCreateParamsIdentityBusinessDetailsIdNumber"]
    ]
    """
    The ID numbers of a business entity.
    """
    monthly_estimated_revenue: NotRequired[
        "AccountCreateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue"
    ]
    """
    An estimate of the monthly revenue of the business.
    """
    phone: NotRequired[str]
    """
    The phone number of the Business Entity.
    """
    registered_name: NotRequired[str]
    """
    The business legal name.
    """
    registration_date: NotRequired[
        "AccountCreateParamsIdentityBusinessDetailsRegistrationDate"
    ]
    """
    When the business was incorporated or registered.
    """
    script_addresses: NotRequired[
        "AccountCreateParamsIdentityBusinessDetailsScriptAddresses"
    ]
    """
    The business registration address of the business entity in non latin script.
    """
    script_names: NotRequired[
        "AccountCreateParamsIdentityBusinessDetailsScriptNames"
    ]
    """
    The business legal name in non latin script.
    """
    structure: NotRequired[
        Literal[
            "cooperative",
            "free_zone_establishment",
            "free_zone_llc",
            "governmental_unit",
            "government_instrumentality",
            "incorporated_association",
            "incorporated_non_profit",
            "incorporated_partnership",
            "limited_liability_partnership",
            "llc",
            "multi_member_llc",
            "private_company",
            "private_corporation",
            "private_partnership",
            "public_company",
            "public_corporation",
            "public_listed_corporation",
            "public_partnership",
            "registered_charity",
            "single_member_llc",
            "sole_establishment",
            "sole_proprietorship",
            "tax_exempt_government_instrumentality",
            "trust",
            "unincorporated_association",
            "unincorporated_non_profit",
            "unincorporated_partnership",
        ]
    ]
    """
    The category identifying the legal structure of the business.
    """


class AccountCreateParamsIdentityBusinessDetailsAddress(TypedDict):
    city: NotRequired[str]
    """
    City, district, suburb, town, or village.
    """
    country: str
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired[str]
    """
    Address line 1 (e.g., street, PO Box, or company name).
    """
    line2: NotRequired[str]
    """
    Address line 2 (e.g., apartment, suite, unit, or building).
    """
    postal_code: NotRequired[str]
    """
    ZIP or postal code.
    """
    state: NotRequired[str]
    """
    State, county, province, or region.
    """
    town: NotRequired[str]
    """
    Town or district.
    """


class AccountCreateParamsIdentityBusinessDetailsAnnualRevenue(TypedDict):
    amount: NotRequired[AmountParam]
    """
    A non-negative integer representing the amount in the smallest currency unit.
    """
    fiscal_year_end: NotRequired[str]
    """
    The close-out date of the preceding fiscal year in ISO 8601 format. E.g. 2023-12-31 for the 31st of December, 2023.
    """


class AccountCreateParamsIdentityBusinessDetailsDocuments(TypedDict):
    bank_account_ownership_verification: NotRequired[
        "AccountCreateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification"
    ]
    """
    One or more documents that support the bank account ownership verification requirement. Must be a document associated with the account's primary active bank account that displays the last 4 digits of the account number, either a statement or a check.
    """
    company_license: NotRequired[
        "AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyLicense"
    ]
    """
    One or more documents that demonstrate proof of a company's license to operate.
    """
    company_memorandum_of_association: NotRequired[
        "AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation"
    ]
    """
    One or more documents showing the company's Memorandum of Association.
    """
    company_ministerial_decree: NotRequired[
        "AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree"
    ]
    """
    Certain countries only: One or more documents showing the ministerial decree legalizing the company's establishment.
    """
    company_registration_verification: NotRequired[
        "AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification"
    ]
    """
    One or more documents that demonstrate proof of a company's registration with the appropriate local authorities.
    """
    company_tax_id_verification: NotRequired[
        "AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification"
    ]
    """
    One or more documents that demonstrate proof of a company's tax ID.
    """
    primary_verification: NotRequired[
        "AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerification"
    ]
    """
    A document verifying the business.
    """
    proof_of_address: NotRequired[
        "AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfAddress"
    ]
    """
    One or more documents that demonstrate proof of address.
    """
    proof_of_registration: NotRequired[
        "AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistration"
    ]
    """
    One or more documents showing the company's proof of registration with the national business registry.
    """
    proof_of_ultimate_beneficial_ownership: NotRequired[
        "AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership"
    ]
    """
    One or more documents that demonstrate proof of ultimate beneficial ownership.
    """


class AccountCreateParamsIdentityBusinessDetailsDocumentsBankAccountOwnershipVerification(
    TypedDict,
):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyLicense(
    TypedDict,
):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMemorandumOfAssociation(
    TypedDict,
):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyMinisterialDecree(
    TypedDict,
):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyRegistrationVerification(
    TypedDict,
):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class AccountCreateParamsIdentityBusinessDetailsDocumentsCompanyTaxIdVerification(
    TypedDict,
):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerification(
    TypedDict,
):
    front_back: "AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack"
    """
    The [file upload](https://docs.stripe.com/api/persons/update#create_file) tokens referring to each side of the document.
    """
    type: Literal["front_back"]
    """
    The format of the verification document. Currently supports `front_back` only.
    """


class AccountCreateParamsIdentityBusinessDetailsDocumentsPrimaryVerificationFrontBack(
    TypedDict,
):
    back: NotRequired[str]
    """
    A [file upload](https://docs.stripe.com/api/persons/update#create_file) token representing the back of the verification document. The purpose of the uploaded file should be 'identity_document'. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
    """
    front: str
    """
    A [file upload](https://docs.stripe.com/api/persons/update#create_file) token representing the front of the verification document. The purpose of the uploaded file should be 'identity_document'. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
    """


class AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfAddress(
    TypedDict,
):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistration(
    TypedDict,
):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    signer: NotRequired[
        "AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner"
    ]
    """
    Person that is signing the document.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfRegistrationSigner(
    TypedDict,
):
    person: str
    """
    Person signing the document.
    """


class AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnership(
    TypedDict,
):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    signer: NotRequired[
        "AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner"
    ]
    """
    Person that is signing the document.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class AccountCreateParamsIdentityBusinessDetailsDocumentsProofOfUltimateBeneficialOwnershipSigner(
    TypedDict,
):
    person: str
    """
    Person signing the document.
    """


class AccountCreateParamsIdentityBusinessDetailsIdNumber(TypedDict):
    registrar: NotRequired[str]
    """
    The registrar of the ID number (Only valid for DE ID number types).
    """
    type: Literal[
        "ae_crn",
        "ae_vat",
        "ao_nif",
        "ar_cuit",
        "at_fn",
        "at_stn",
        "at_vat",
        "au_abn",
        "au_acn",
        "au_in",
        "az_tin",
        "bd_etin",
        "be_cbe",
        "be_vat",
        "bg_uic",
        "bg_vat",
        "bm_crn",
        "bo_tin",
        "br_cnpj",
        "bt_tpn",
        "ca_cn",
        "ca_crarr",
        "ca_gst_hst",
        "ca_neq",
        "ca_rid",
        "ch_chid",
        "ch_uid",
        "co_nit",
        "cr_cpj",
        "cr_nite",
        "cy_he",
        "cy_tic",
        "cy_vat",
        "cz_ico",
        "cz_vat",
        "de_hrn",
        "de_stn",
        "de_vat",
        "dk_cvr",
        "dk_vat",
        "do_rcn",
        "ec_ruc",
        "ee_rk",
        "ee_vat",
        "eg_tin",
        "es_cif",
        "es_vat",
        "fi_vat",
        "fi_yt",
        "fr_rna",
        "fr_siren",
        "fr_vat",
        "gb_crn",
        "gb_vat",
        "gh_tin",
        "gi_crn",
        "gr_afm",
        "gr_gemi",
        "gr_vat",
        "gt_nit",
        "gy_tin",
        "hk_br",
        "hk_cr",
        "hn_rtn",
        "hr_mbs",
        "hr_oib",
        "hr_vat",
        "hu_cjs",
        "hu_tin",
        "hu_vat",
        "ie_crn",
        "ie_trn",
        "ie_vat",
        "it_rea",
        "it_vat",
        "jm_trn",
        "jo_crn",
        "jp_cn",
        "ke_pin",
        "ky_crn",
        "kz_bin",
        "li_uid",
        "lk_tin",
        "lt_ccrn",
        "lt_vat",
        "lu_nif",
        "lu_rcs",
        "lu_vat",
        "lv_urn",
        "lv_vat",
        "mo_tin",
        "mt_crn",
        "mt_tin",
        "mt_vat",
        "mv_tin",
        "mx_rfc",
        "my_brn",
        "my_coid",
        "my_itn",
        "my_sst",
        "mz_nuit",
        "ng_tin",
        "nl_kvk",
        "nl_rsin",
        "nl_vat",
        "no_orgnr",
        "nz_bn",
        "nz_ird",
        "pa_ruc",
        "pe_ruc",
        "ph_tin",
        "pk_ntn",
        "pl_nip",
        "pl_regon",
        "pl_vat",
        "pt_vat",
        "py_ruc",
        "ro_cui",
        "ro_orc",
        "ro_vat",
        "sa_crn",
        "sa_tin",
        "se_orgnr",
        "se_vat",
        "sg_uen",
        "si_msp",
        "si_tin",
        "si_vat",
        "sk_dic",
        "sk_ico",
        "sk_vat",
        "sl_tin",
        "sv_nit",
        "th_crn",
        "th_prn",
        "th_tin",
        "us_ein",
        "uy_ruc",
        "vg_cn",
        "za_tin",
    ]
    """
    Open Enum. The ID number type of a business entity.
    """
    value: str
    """
    The value of the ID number.
    """


class AccountCreateParamsIdentityBusinessDetailsMonthlyEstimatedRevenue(
    TypedDict,
):
    amount: NotRequired[AmountParam]
    """
    A non-negative integer representing the amount in the smallest currency unit.
    """


class AccountCreateParamsIdentityBusinessDetailsRegistrationDate(TypedDict):
    day: int
    """
    The day of registration, between 1 and 31.
    """
    month: int
    """
    The month of registration, between 1 and 12.
    """
    year: int
    """
    The four-digit year of registration.
    """


class AccountCreateParamsIdentityBusinessDetailsScriptAddresses(TypedDict):
    kana: NotRequired[
        "AccountCreateParamsIdentityBusinessDetailsScriptAddressesKana"
    ]
    """
    Kana Address.
    """
    kanji: NotRequired[
        "AccountCreateParamsIdentityBusinessDetailsScriptAddressesKanji"
    ]
    """
    Kanji Address.
    """


class AccountCreateParamsIdentityBusinessDetailsScriptAddressesKana(TypedDict):
    city: NotRequired[str]
    """
    City, district, suburb, town, or village.
    """
    country: str
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired[str]
    """
    Address line 1 (e.g., street, PO Box, or company name).
    """
    line2: NotRequired[str]
    """
    Address line 2 (e.g., apartment, suite, unit, or building).
    """
    postal_code: NotRequired[str]
    """
    ZIP or postal code.
    """
    state: NotRequired[str]
    """
    State, county, province, or region.
    """
    town: NotRequired[str]
    """
    Town or district.
    """


class AccountCreateParamsIdentityBusinessDetailsScriptAddressesKanji(
    TypedDict
):
    city: NotRequired[str]
    """
    City, district, suburb, town, or village.
    """
    country: str
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired[str]
    """
    Address line 1 (e.g., street, PO Box, or company name).
    """
    line2: NotRequired[str]
    """
    Address line 2 (e.g., apartment, suite, unit, or building).
    """
    postal_code: NotRequired[str]
    """
    ZIP or postal code.
    """
    state: NotRequired[str]
    """
    State, county, province, or region.
    """
    town: NotRequired[str]
    """
    Town or district.
    """


class AccountCreateParamsIdentityBusinessDetailsScriptNames(TypedDict):
    kana: NotRequired[
        "AccountCreateParamsIdentityBusinessDetailsScriptNamesKana"
    ]
    """
    Kana name.
    """
    kanji: NotRequired[
        "AccountCreateParamsIdentityBusinessDetailsScriptNamesKanji"
    ]
    """
    Kanji name.
    """


class AccountCreateParamsIdentityBusinessDetailsScriptNamesKana(TypedDict):
    registered_name: NotRequired[str]
    """
    Registered name of the business.
    """


class AccountCreateParamsIdentityBusinessDetailsScriptNamesKanji(TypedDict):
    registered_name: NotRequired[str]
    """
    Registered name of the business.
    """


class AccountCreateParamsIdentityIndividual(TypedDict):
    additional_addresses: NotRequired[
        List["AccountCreateParamsIdentityIndividualAdditionalAddress"]
    ]
    """
    Additional addresses associated with the individual.
    """
    additional_names: NotRequired[
        List["AccountCreateParamsIdentityIndividualAdditionalName"]
    ]
    """
    Additional names (e.g. aliases) associated with the individual.
    """
    address: NotRequired["AccountCreateParamsIdentityIndividualAddress"]
    """
    The individual's residential address.
    """
    date_of_birth: NotRequired[
        "AccountCreateParamsIdentityIndividualDateOfBirth"
    ]
    """
    The individual's date of birth.
    """
    documents: NotRequired["AccountCreateParamsIdentityIndividualDocuments"]
    """
    Documents that may be submitted to satisfy various informational requests.
    """
    email: NotRequired[str]
    """
    The individual's email address. You can only set this field when the Account is configured as a `merchant` or `recipient`. Use `contact_email` as the primary contact email for this Account.
    """
    given_name: NotRequired[str]
    """
    The individual's first name.
    """
    id_numbers: NotRequired[
        List["AccountCreateParamsIdentityIndividualIdNumber"]
    ]
    """
    The identification numbers (e.g., SSN) associated with the individual.
    """
    legal_gender: NotRequired[Literal["female", "male"]]
    """
    The individual's gender (International regulations require either "male" or "female").
    """
    metadata: NotRequired["Dict[str, str]|UntypedStripeObject[str]"]
    """
    Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
    """
    nationalities: NotRequired[List[str]]
    """
    The countries where the individual is a national. Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    phone: NotRequired[str]
    """
    The individual's phone number.
    """
    political_exposure: NotRequired[Literal["existing", "none"]]
    """
    The individual's political exposure.
    """
    relationship: NotRequired[
        "AccountCreateParamsIdentityIndividualRelationship"
    ]
    """
    The relationship that this individual has with the account's identity.
    """
    script_addresses: NotRequired[
        "AccountCreateParamsIdentityIndividualScriptAddresses"
    ]
    """
    The script addresses (e.g., non-Latin characters) associated with the individual.
    """
    script_names: NotRequired[
        "AccountCreateParamsIdentityIndividualScriptNames"
    ]
    """
    The individuals primary name in non latin script.
    """
    surname: NotRequired[str]
    """
    The individual's last name.
    """


class AccountCreateParamsIdentityIndividualAdditionalAddress(TypedDict):
    city: NotRequired[str]
    """
    City, district, suburb, town, or village.
    """
    country: str
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired[str]
    """
    Address line 1 (e.g., street, PO Box, or company name).
    """
    line2: NotRequired[str]
    """
    Address line 2 (e.g., apartment, suite, unit, or building).
    """
    postal_code: NotRequired[str]
    """
    ZIP or postal code.
    """
    purpose: Literal["registered"]
    """
    Purpose of additional address.
    """
    state: NotRequired[str]
    """
    State, county, province, or region.
    """
    town: NotRequired[str]
    """
    Town or district.
    """


class AccountCreateParamsIdentityIndividualAdditionalName(TypedDict):
    full_name: NotRequired[str]
    """
    The person's full name.
    """
    given_name: NotRequired[str]
    """
    The person's first or given name.
    """
    purpose: Literal["alias", "maiden"]
    """
    The purpose or type of the additional name.
    """
    surname: NotRequired[str]
    """
    The person's last or family name.
    """


class AccountCreateParamsIdentityIndividualAddress(TypedDict):
    city: NotRequired[str]
    """
    City, district, suburb, town, or village.
    """
    country: str
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired[str]
    """
    Address line 1 (e.g., street, PO Box, or company name).
    """
    line2: NotRequired[str]
    """
    Address line 2 (e.g., apartment, suite, unit, or building).
    """
    postal_code: NotRequired[str]
    """
    ZIP or postal code.
    """
    state: NotRequired[str]
    """
    State, county, province, or region.
    """
    town: NotRequired[str]
    """
    Town or district.
    """


class AccountCreateParamsIdentityIndividualDateOfBirth(TypedDict):
    day: int
    """
    The day of birth.
    """
    month: int
    """
    The month of birth.
    """
    year: int
    """
    The year of birth.
    """


class AccountCreateParamsIdentityIndividualDocuments(TypedDict):
    company_authorization: NotRequired[
        "AccountCreateParamsIdentityIndividualDocumentsCompanyAuthorization"
    ]
    """
    One or more documents that demonstrate proof that this person is authorized to represent the company.
    """
    passport: NotRequired[
        "AccountCreateParamsIdentityIndividualDocumentsPassport"
    ]
    """
    One or more documents showing the person's passport page with photo and personal data.
    """
    primary_verification: NotRequired[
        "AccountCreateParamsIdentityIndividualDocumentsPrimaryVerification"
    ]
    """
    An identifying document showing the person's name, either a passport or local ID card.
    """
    secondary_verification: NotRequired[
        "AccountCreateParamsIdentityIndividualDocumentsSecondaryVerification"
    ]
    """
    A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
    """
    visa: NotRequired["AccountCreateParamsIdentityIndividualDocumentsVisa"]
    """
    One or more documents showing the person's visa required for living in the country where they are residing.
    """


class AccountCreateParamsIdentityIndividualDocumentsCompanyAuthorization(
    TypedDict,
):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class AccountCreateParamsIdentityIndividualDocumentsPassport(TypedDict):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class AccountCreateParamsIdentityIndividualDocumentsPrimaryVerification(
    TypedDict,
):
    front_back: "AccountCreateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack"
    """
    The [file upload](https://docs.stripe.com/api/persons/update#create_file) tokens referring to each side of the document.
    """
    type: Literal["front_back"]
    """
    The format of the verification document. Currently supports `front_back` only.
    """


class AccountCreateParamsIdentityIndividualDocumentsPrimaryVerificationFrontBack(
    TypedDict,
):
    back: NotRequired[str]
    """
    A [file upload](https://docs.stripe.com/api/persons/update#create_file) token representing the back of the verification document. The purpose of the uploaded file should be 'identity_document'. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
    """
    front: str
    """
    A [file upload](https://docs.stripe.com/api/persons/update#create_file) token representing the front of the verification document. The purpose of the uploaded file should be 'identity_document'. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
    """


class AccountCreateParamsIdentityIndividualDocumentsSecondaryVerification(
    TypedDict,
):
    front_back: "AccountCreateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack"
    """
    The [file upload](https://docs.stripe.com/api/persons/update#create_file) tokens referring to each side of the document.
    """
    type: Literal["front_back"]
    """
    The format of the verification document. Currently supports `front_back` only.
    """


class AccountCreateParamsIdentityIndividualDocumentsSecondaryVerificationFrontBack(
    TypedDict,
):
    back: NotRequired[str]
    """
    A [file upload](https://docs.stripe.com/api/persons/update#create_file) token representing the back of the verification document. The purpose of the uploaded file should be 'identity_document'. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
    """
    front: str
    """
    A [file upload](https://docs.stripe.com/api/persons/update#create_file) token representing the front of the verification document. The purpose of the uploaded file should be 'identity_document'. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
    """


class AccountCreateParamsIdentityIndividualDocumentsVisa(TypedDict):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class AccountCreateParamsIdentityIndividualIdNumber(TypedDict):
    type: Literal[
        "ae_eid",
        "ao_nif",
        "ar_cuil",
        "ar_dni",
        "at_stn",
        "az_tin",
        "bd_brc",
        "bd_etin",
        "bd_nid",
        "be_nrn",
        "bg_ucn",
        "bm_pp",
        "bn_nric",
        "bo_ci",
        "br_cpf",
        "bt_cid",
        "ca_sin",
        "ch_oasi",
        "cl_rut",
        "cn_pp",
        "co_nuip",
        "cr_ci",
        "cr_cpf",
        "cr_dimex",
        "cr_nite",
        "cy_tic",
        "cz_rc",
        "de_stn",
        "dk_cpr",
        "do_cie",
        "do_rcn",
        "ec_ci",
        "ee_ik",
        "eg_tin",
        "es_nif",
        "fi_hetu",
        "fr_nir",
        "gb_nino",
        "gh_pin",
        "gr_afm",
        "gt_nit",
        "gy_tin",
        "hk_id",
        "hn_rtn",
        "hr_oib",
        "hu_ad",
        "id_nik",
        "ie_ppsn",
        "is_kt",
        "it_cf",
        "jm_trn",
        "jo_pin",
        "jp_inc",
        "ke_pin",
        "ky_pp",
        "kz_iin",
        "li_peid",
        "lk_nic",
        "lt_ak",
        "lu_nif",
        "lv_pk",
        "mo_bir",
        "mt_nic",
        "mv_tin",
        "mx_rfc",
        "my_nric",
        "mz_nuit",
        "ng_nin",
        "nl_bsn",
        "no_nin",
        "nz_ird",
        "pa_ruc",
        "pe_dni",
        "ph_tin",
        "pk_cnic",
        "pk_snic",
        "pl_pesel",
        "pt_nif",
        "py_ruc",
        "ro_cnp",
        "sa_tin",
        "se_pin",
        "sg_fin",
        "sg_nric",
        "si_pin",
        "sk_dic",
        "sv_nit",
        "th_lc",
        "th_pin",
        "tr_tin",
        "us_itin",
        "us_itin_last_4",
        "us_ssn",
        "us_ssn_last_4",
        "uy_dni",
        "vg_pp",
        "za_id",
    ]
    """
    The ID number type of an individual.
    """
    value: str
    """
    The value of the ID number.
    """


class AccountCreateParamsIdentityIndividualRelationship(TypedDict):
    director: NotRequired[bool]
    """
    Whether the person is a director of the account's identity. Directors are typically members of the governing board of the company, or responsible for ensuring the company meets its regulatory obligations.
    """
    executive: NotRequired[bool]
    """
    Whether the person has significant responsibility to control, manage, or direct the organization.
    """
    owner: NotRequired[bool]
    """
    Whether the person is an owner of the account's identity.
    """
    percent_ownership: NotRequired[Decimal]
    """
    The percent owned by the person of the account's legal entity.
    """
    title: NotRequired[str]
    """
    The person's title (e.g., CEO, Support Engineer).
    """


class AccountCreateParamsIdentityIndividualScriptAddresses(TypedDict):
    kana: NotRequired[
        "AccountCreateParamsIdentityIndividualScriptAddressesKana"
    ]
    """
    Kana Address.
    """
    kanji: NotRequired[
        "AccountCreateParamsIdentityIndividualScriptAddressesKanji"
    ]
    """
    Kanji Address.
    """


class AccountCreateParamsIdentityIndividualScriptAddressesKana(TypedDict):
    city: NotRequired[str]
    """
    City, district, suburb, town, or village.
    """
    country: str
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired[str]
    """
    Address line 1 (e.g., street, PO Box, or company name).
    """
    line2: NotRequired[str]
    """
    Address line 2 (e.g., apartment, suite, unit, or building).
    """
    postal_code: NotRequired[str]
    """
    ZIP or postal code.
    """
    state: NotRequired[str]
    """
    State, county, province, or region.
    """
    town: NotRequired[str]
    """
    Town or district.
    """


class AccountCreateParamsIdentityIndividualScriptAddressesKanji(TypedDict):
    city: NotRequired[str]
    """
    City, district, suburb, town, or village.
    """
    country: str
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired[str]
    """
    Address line 1 (e.g., street, PO Box, or company name).
    """
    line2: NotRequired[str]
    """
    Address line 2 (e.g., apartment, suite, unit, or building).
    """
    postal_code: NotRequired[str]
    """
    ZIP or postal code.
    """
    state: NotRequired[str]
    """
    State, county, province, or region.
    """
    town: NotRequired[str]
    """
    Town or district.
    """


class AccountCreateParamsIdentityIndividualScriptNames(TypedDict):
    kana: NotRequired["AccountCreateParamsIdentityIndividualScriptNamesKana"]
    """
    Persons name in kana script.
    """
    kanji: NotRequired["AccountCreateParamsIdentityIndividualScriptNamesKanji"]
    """
    Persons name in kanji script.
    """


class AccountCreateParamsIdentityIndividualScriptNamesKana(TypedDict):
    given_name: NotRequired[str]
    """
    The person's first or given name.
    """
    surname: NotRequired[str]
    """
    The person's last or family name.
    """


class AccountCreateParamsIdentityIndividualScriptNamesKanji(TypedDict):
    given_name: NotRequired[str]
    """
    The person's first or given name.
    """
    surname: NotRequired[str]
    """
    The person's last or family name.
    """
